@@ -21,6 +21,10 @@
 #include "sort.h"
 #include "mx.h"
 
+#ifdef USE_IMAP
+#include "imap_private.h"
+#endif
+
 void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
 {
   int changed = h->changed;
@@ -33,16 +37,24 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
   switch (flag)
   {
     case M_DELETE:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_DELETE))
+			return;
+#endif
+
       if (bf)
       {
-	if (!h->deleted)
+	if (!h->deleted && !ctx->readonly)
 	{
 	  h->deleted = 1;
 	  if (upd_ctx) ctx->deleted++;
 #ifdef USE_IMAP
           /* deleted messages aren't treated as changed elsewhere so that the
            * purge-on-sync option works correctly. This isn't applicable here */
-          if (ctx->magic == M_IMAP)
+          if (ctx && ctx->magic == M_IMAP)
           {
             h->changed = 1;
 	    if (upd_ctx) ctx->changed = 1;
@@ -76,6 +88,14 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
       break;
 
     case M_NEW:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_SEEN))
+			return;
+#endif
+
       if (bf)
       {
 	if (h->read || h->old)
@@ -103,6 +123,14 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
       break;
 
     case M_OLD:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_SEEN))
+			return;
+#endif
+
       if (bf)
       {
 	if (!h->old)
@@ -125,6 +153,14 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
       break;
 
     case M_READ:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_SEEN))
+			return;
+#endif
+
       if (bf)
       {
 	if (!h->read)
@@ -149,6 +185,14 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
       break;
 
     case M_REPLIED:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_WRITE))
+			return;
+#endif
+
       if (bf)
       {
 	if (!h->replied)
@@ -174,6 +218,14 @@ void _mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf, int upd_ctx)
       break;
 
     case M_FLAG:
+
+#ifdef USE_IMAP
+	if (ctx && ctx->magic == M_IMAP)
+		if (mutt_bit_isset (((IMAP_DATA *)ctx->data)->capabilities, ACL) \
+		&& !mutt_bit_isset(((IMAP_DATA *)ctx->data)->rights,IMAP_ACL_WRITE))
+			return;
+#endif
+
       if (bf)
       {
 	if (!h->flagged)
