@@ -20,17 +20,8 @@
 #include "mutt_curses.h"
 #include "sort.h"
 #include "charset.h"
-
-
-#ifdef HAVE_PGP
-#include "pgp.h"
-#endif
-
-#ifdef HAVE_SMIME
-#include "smime.h"
-#endif
-
-
+#include "mutt_crypt.h"
+#include "mutt_idna.h"
 
 #include <ctype.h>
 #include <stdlib.h>
@@ -205,6 +196,7 @@ int mutt_user_is_recipient (HEADER *h)
 }
 
 /* %a = address of author
+ * %A = reply-to address (if present; otherwise: address of author
  * %b = filename of the originating folder
  * %B = the list to which the letter was sent
  * %c = size of message in bytes
@@ -267,10 +259,18 @@ hdr_format_str (char *dest,
   dest[0] = 0;
   switch (op)
   {
+    case 'A':
+      if(hdr->env->reply_to && hdr->env->reply_to->mailbox)
+      {
+	mutt_format_s (dest, destlen, prefix, mutt_addr_for_display (hdr->env->reply_to));
+	break;
+      }
+      /* fall through if 'A' returns nothing */
+
     case 'a':
       if(hdr->env->from && hdr->env->from->mailbox)
       {
-	mutt_format_s (dest, destlen, prefix, hdr->env->from->mailbox);
+	mutt_format_s (dest, destlen, prefix, mutt_addr_for_display (hdr->env->from));
       }
       else
         dest[0] = '\0';
@@ -430,7 +430,7 @@ hdr_format_str (char *dest,
 
     case 'f':
       buf2[0] = 0;
-      rfc822_write_address (buf2, sizeof (buf2), hdr->env->from);
+      rfc822_write_address (buf2, sizeof (buf2), hdr->env->from, 1);
       mutt_format_s (dest, destlen, prefix, buf2);
       break;
 
@@ -594,7 +594,7 @@ hdr_format_str (char *dest,
     case 'u':
       if (hdr->env->from && hdr->env->from->mailbox)
       {
-	strfcpy (buf2, hdr->env->from->mailbox, sizeof (buf2));
+	strfcpy (buf2, mutt_addr_for_display (hdr->env->from), sizeof (buf2));
 	if ((p = strpbrk (buf2, "%@")))
 	  *p = 0;
       }
@@ -624,18 +624,14 @@ hdr_format_str (char *dest,
     
       ch = ' ';
 
-#if defined(HAVE_PGP) || defined(HAVE_SMIME)
-      if (hdr->security & GOODSIGN)
+      if (WithCrypto && hdr->security & GOODSIGN)
         ch = 'S';
-      else if (hdr->security & ENCRYPT)
+      else if (WithCrypto && hdr->security & ENCRYPT)
       	ch = 'P';
-      else if (hdr->security & SIGN)
+      else if (WithCrypto && hdr->security & SIGN)
         ch = 's';
-#ifdef HAVE_PGP
-      else if (hdr->security & PGPKEY)
+      else if ((WithCrypto & APPLICATION_PGP) && hdr->security & PGPKEY)
         ch = 'K';
-#endif
-#endif
 
       snprintf (buf2, sizeof (buf2),
 		"%c%c%c", (THREAD_NEW ? 'n' : (THREAD_OLD ? 'o' : 
