@@ -139,7 +139,8 @@ int mutt_extract_token (BUFFER *dest, BUFFER *tok, int flags)
 	case 'C':
 	    if (!*tok->dptr)
 		return -1; /* premature end of token */
-	  mutt_buffer_addch (dest, (toupper (*tok->dptr) - '@') & 0x7f);
+	  mutt_buffer_addch (dest, (toupper ((unsigned char) *tok->dptr)
+                                    - '@') & 0x7f);
 	  tok->dptr++;
 	  break;
 	case 'r':
@@ -180,7 +181,7 @@ int mutt_extract_token (BUFFER *dest, BUFFER *tok, int flags)
       else if (ch == '[')
 	mutt_buffer_addch (dest, '\033');
       else if (isalpha ((unsigned char) ch))
-	mutt_buffer_addch (dest, toupper (ch) - '@');
+	mutt_buffer_addch (dest, toupper ((unsigned char) ch) - '@');
       else
       {
 	mutt_buffer_addch (dest, '^');
@@ -1063,9 +1064,6 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	  case M_MMDF:
 	    p = "MMDF";
 	    break;
-	  case M_KENDRA:
-	    p = "KENDRA";
-	    break;
 	  case M_MH:
 	    p = "MH";
 	    break;
@@ -1173,7 +1171,7 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
     }
     else if (DTYPE (MuttVars[idx].type) == DT_SORT)
     {
-      const struct mapping_t *map;
+      const struct mapping_t *map = NULL;
 
       switch (MuttVars[idx].type & DT_SUBTYPE_MASK)
       {
@@ -1195,6 +1193,13 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	  break;
       }
 
+      if (!map)
+      {
+	snprintf (err->data, err->dsize, _("%s: Unknown type."), MuttVars[idx].option);
+	r = -1;
+	break;
+      }
+      
       if (query || *s->dptr != '=')
       {
 	p = mutt_getnamebyvalue (*((short *) MuttVars[idx].data) & SORT_MASK, map);
