@@ -30,6 +30,8 @@
 
 extern int Charset_is_utf8; /* FIXME: bad modularisation */
 
+extern size_t UngetCount;
+
 static void print_enriched_string (int attr, unsigned char *s, int do_color)
 {
   wchar_t wc;
@@ -798,6 +800,34 @@ static int menu_dialog_dokey (MUTTMENU *menu, int *ip)
   }
 }
 
+int menu_redraw (MUTTMENU *menu)
+{
+  /* See if all or part of the screen needs to be updated.  */
+  if (menu->redraw & REDRAW_FULL)
+  {
+    menu_redraw_full (menu);
+    /* allow the caller to do any local configuration */
+    return (OP_REDRAW);
+  }
+  
+  if (!menu->dialog)
+    menu_check_recenter (menu);
+  
+  if (menu->redraw & REDRAW_STATUS)
+    menu_redraw_status (menu);
+  if (menu->redraw & REDRAW_INDEX)
+    menu_redraw_index (menu);
+  else if (menu->redraw & (REDRAW_MOTION | REDRAW_MOTION_RESYNCH))
+    menu_redraw_motion (menu);
+  else if (menu->redraw == REDRAW_CURRENT)
+    menu_redraw_current (menu);
+  
+  if (menu->dialog)
+    menu_redraw_prompt (menu);
+  
+  return OP_NULL;
+}
+
 int mutt_menuLoop (MUTTMENU *menu)
 {
   int i = OP_NULL;
@@ -817,28 +847,8 @@ int mutt_menuLoop (MUTTMENU *menu)
     imap_keepalive ();
 #endif
 
-    /* See if all or part of the screen needs to be updated.  */
-    if (menu->redraw & REDRAW_FULL)
-    {
-      menu_redraw_full (menu);
-      /* allow the caller to do any local configuration */
-      return (OP_REDRAW);
-    }
-
-    if (!menu->dialog)
-      menu_check_recenter (menu);
-
-    if (menu->redraw & REDRAW_STATUS)
-      menu_redraw_status (menu);
-    if (menu->redraw & REDRAW_INDEX)
-      menu_redraw_index (menu);
-    else if (menu->redraw & (REDRAW_MOTION | REDRAW_MOTION_RESYNCH))
-      menu_redraw_motion (menu);
-    else if (menu->redraw == REDRAW_CURRENT)
-      menu_redraw_current (menu);
-
-    if (menu->dialog)
-      menu_redraw_prompt (menu);
+    if (menu_redraw (menu) == OP_REDRAW)
+      return OP_REDRAW;
     
     menu->oldcurrent = menu->current;
 
@@ -854,7 +864,7 @@ int mutt_menuLoop (MUTTMENU *menu)
       return i;
 		    
     i = km_dokey (menu->menu);
-    if (i == OP_TAG_PREFIX)
+    if (i == OP_TAG_PREFIX || i == OP_TAG_PREFIX_COND)
     {
       if (menu->tagged)
       {
@@ -864,11 +874,22 @@ int mutt_menuLoop (MUTTMENU *menu)
 	menu->tagprefix = 1;
 	CLEARLINE (LINES - 1);
       }
-      else 
+      else if (i == OP_TAG_PREFIX)
       {
 	mutt_error _("No tagged entries.");
 	i = -1;
       }
+      else /* None tagged, OP_TAG_PREFIX_COND */
+      {
+	event_t tmp;
+	while(UngetCount>0)
+	{
+	  tmp=mutt_getch();
+	  if(tmp.op==OP_END_COND)break;
+	}
+	mutt_message _("Nothing to do.");
+	i = -1;
+      }
     }
     else if (menu->tagged && option (OPTAUTOTAG))
       menu->tagprefix = 1;
@@ -1032,6 +1053,9 @@ int mutt_menuLoop (MUTTMENU *menu)
 	km_error_key (menu->menu);
 	break;
 
+      case OP_END_COND:
+	break;
+
       default:
 	return (i);
     }
