@@ -432,25 +432,14 @@ static int include_reply (CONTEXT *ctx, HEADER *cur, FILE *out)
   return 0;
 }
 
-static int default_to (ADDRESS **to, ENVELOPE *env, int flags)
+static int default_to (ADDRESS **to, ENVELOPE *env, int flags, int hmfupto)
 {
   char prompt[STRING];
 
-  if (flags && env->mail_followup_to)
+  if (flags && env->mail_followup_to && hmfupto == M_YES) 
   {
-    snprintf (prompt, sizeof (prompt), _("Follow-up to %s%s?"),
-	      env->mail_followup_to->mailbox,
-	      env->mail_followup_to->next ? ",..." : "");
-
-    switch (query_quadoption (OPT_MFUPTO, prompt))
-    {
-    case M_YES:
-      rfc822_append (to, env->mail_followup_to);
-      return 0;
-
-    case -1:
-      return -1; /* abort */
-    }
+    rfc822_append (to, env->mail_followup_to);
+    return 0;
   }
 
   /* Exit now if we're setting up the default Cc list for list-reply
@@ -519,23 +508,36 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int flags)
 
 int mutt_fetch_recips (ENVELOPE *out, ENVELOPE *in, int flags)
 {
+  char prompt[STRING];
   ADDRESS *tmp;
+  int hmfupto = -1;
+
+  if ((flags & (SENDLISTREPLY|SENDGROUPREPLY)) && in->mail_followup_to)
+  {
+    snprintf (prompt, sizeof (prompt), _("Follow-up to %s%s?"),
+	      in->mail_followup_to->mailbox,
+	      in->mail_followup_to->next ? ",..." : "");
+
+    if ((hmfupto = query_quadoption (OPT_MFUPTO, prompt)) == -1)
+      return -1;
+  }
+
   if (flags & SENDLISTREPLY)
   {
     tmp = find_mailing_lists (in->to, in->cc);
     rfc822_append (&out->to, tmp);
     rfc822_free_address (&tmp);
 
-    if (in->mail_followup_to &&
-        default_to (&out->cc, in, flags & SENDLISTREPLY) == -1)
+    if (in->mail_followup_to && hmfupto == M_YES &&
+        default_to (&out->cc, in, flags & SENDLISTREPLY, hmfupto) == -1)
       return (-1); /* abort */
   }
   else
   {
-    if (default_to (&out->to, in, flags & SENDGROUPREPLY) == -1)
+    if (default_to (&out->to, in, flags & SENDGROUPREPLY, hmfupto) == -1)
       return (-1); /* abort */
 
-    if ((flags & SENDGROUPREPLY) && !in->mail_followup_to)
+    if ((flags & SENDGROUPREPLY) && (!in->mail_followup_to || hmfupto != M_YES))
     {
       /* if(!mutt_addr_is_user(in->to)) */
       rfc822_append (&out->cc, in->to);
@@ -1250,36 +1252,50 @@ ci_send_message (int flags,		/* send mode */
 	msg->security |= ENCRYPT;
       if (option (OPTCRYPTREPLYSIGN) && cur && (cur->security & SIGN))
 	msg->security |= SIGN;
-      if (option (OPTCRYPTREPLYSIGNENCRYPTED) && cur && cur->security & ENCRYPT)
+      if (option (OPTCRYPTREPLYSIGNENCRYPTED) && cur && (cur->security & ENCRYPT))
 	msg->security |= SIGN;
     }      
 
-    if (WithCrypto && msg->security && cur)
+    if (WithCrypto && msg->security)
     {
-      if ((WithCrypto & APPLICATION_SMIME)
-          && ((cur->security & APPLICATION_SMIME)
-              || option (OPTSMIMEISDEFAULT)))
-        msg->security |= APPLICATION_SMIME;
-
-      if ((WithCrypto & APPLICATION_PGP) && (cur->security & APPLICATION_PGP))
+      /* 
+       * When reypling / forwarding, use the original message's
+       * crypto system.  According to the documentation,
+       * smime_is_default should be disregarded here.
+       * 
+       * Problem: At least with forwarding, this doesn't really
+       * make much sense. Should we have an option to completely
+       * disable individual mechanisms at run-time?
+       */
+      if (cur)
       {
-	msg->security &= ~APPLICATION_SMIME;
-        msg->security |= APPLICATION_PGP;
+	if ((WithCrypto & APPLICATION_PGP) && option (OPTCRYPTAUTOPGP) 
+	    && (cur->security & APPLICATION_PGP))
+	  msg->security |= APPLICATION_PGP;
+	else if ((WithCrypto & APPLICATION_SMIME) && option (OPTCRYPTAUTOSMIME)
+		 && (cur->security & APPLICATION_SMIME))
+	  msg->security |= APPLICATION_SMIME;
       }
-      if ((WithCrypto & APPLICATION_SMIME)
-          && !(cur->security & (APPLICATION_PGP|APPLICATION_SMIME)))
-	msg->security |= APPLICATION_PGP;
-    }
-    else if ((WithCrypto & APPLICATION_PGP) && msg->security)
-    {
-      msg->security |= APPLICATION_PGP;
-      if ((WithCrypto & APPLICATION_SMIME) && option (OPTSMIMEISDEFAULT))
+      
+      /*
+       * No crypto mechanism selected? Use availability + smime_is_default
+       * for the decision. 
+       */
+      if (!(msg->security & (APPLICATION_SMIME | APPLICATION_PGP)))
       {
-        msg->security |= APPLICATION_SMIME;
-        msg->security &= ~APPLICATION_PGP;
+	if ((WithCrypto & APPLICATION_SMIME) && option (OPTCRYPTAUTOSMIME) 
+	    && option (OPTSMIMEISDEFAULT))
+	  msg->security |= APPLICATION_SMIME;
+	else if ((WithCrypto & APPLICATION_PGP) && option (OPTCRYPTAUTOPGP))
+	  msg->security |= APPLICATION_PGP;
+	else if ((WithCrypto & APPLICATION_SMIME) && option (OPTCRYPTAUTOSMIME))
+	  msg->security |= APPLICATION_SMIME;
       }
     }
-
+    
+    /* No permissible mechanisms found.  Don't sign or encrypt. */
+    if (!(msg->security & (APPLICATION_SMIME|APPLICATION_PGP)))
+      msg->security = 0;
   }
   /* wait until now to set the real name portion of our return address so
      that $realname can be set in a send-hook */
@@ -1337,7 +1353,7 @@ ci_send_message (int flags,		/* send mode */
       if (stat (msg->content->filename, &st) == 0)
       {
 	/* if the file was not modified, bail out now */
-	if (mtime == st.st_mtime &&
+	if (mtime == st.st_mtime && !msg->content->next &&
 	    query_quadoption (OPT_ABORT, _("Abort unmodified message?")) == M_YES)
 	{
 	  mutt_message _("Aborted unmodified message.");
