@@ -18,6 +18,7 @@
 
 #include "mutt.h"
 #include "sort.h"
+#include "mutt_idna.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -85,7 +86,7 @@ int compare_subject (const void *a, const void *b)
   return (SORTCODE (rc));
 }
 
-char *mutt_get_name (ADDRESS *a)
+const char *mutt_get_name (ADDRESS *a)
 {
   ADDRESS *ali;
 
@@ -96,7 +97,7 @@ char *mutt_get_name (ADDRESS *a)
     else if (a->personal)
       return a->personal;
     else if (a->mailbox)
-      return (a->mailbox);
+      return (mutt_addr_for_display (a));
   }
   /* don't return NULL to avoid segfault when printing/comparing */
   return ("");
@@ -106,7 +107,7 @@ int compare_to (const void *a, const void *b)
 {
   HEADER **ppa = (HEADER **) a;
   HEADER **ppb = (HEADER **) b;
-  char *fa, *fb;
+  const char *fa, *fb;
   int result;
 
   fa = mutt_get_name ((*ppa)->env->to);
@@ -120,7 +121,7 @@ int compare_from (const void *a, const void *b)
 {
   HEADER **ppa = (HEADER **) a;
   HEADER **ppb = (HEADER **) b;
-  char *fa, *fb;
+  const char *fa, *fb;
   int result;
 
   fa = mutt_get_name ((*ppa)->env->from);
